utils::globalVariables(
  c(
    ".data",
    ":=",
    "IMPID",
    "description",
    "est",
    "lci",
    "lsm_type",
    "n_miss",
    "original_id",
    "parameter",
    "parameter_type",
    "pct_miss",
    "pval",
    "remainder",
    "se",
    "uci",
    "visit",
    "binomial",
    "STAT",
    "TRTVAL"
  )
)


#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL
